==> webkit2gtk_2.51.1.orig.tar.xz: webkitgtk-2.51.1/Source/WebCore/Modules/webxr/WebXRTransientInputHitTestResult.h <==
/*
 * Copyright (C) 2025 Igalia S.L. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEBXR_HIT_TEST)

#include <wtf/Ref.h>
#include <wtf/RefCounted.h>
#include <wtf/TZoneMalloc.h>
#include <wtf/Vector.h>

namespace WebCore {

class WebXRInputSource;
class WebXRHitTestResult;

class WebXRTransientInputHitTestResult : public RefCounted<WebXRTransientInputHitTestResult> {
    WTF_MAKE_TZONE_OR_ISO_ALLOCATED(WebXRTransientInputHitTestResult);
public:
    static Ref<WebXRTransientInputHitTestResult> create(Ref<WebXRInputSource>&&, Vector<RefPtr<WebXRHitTestResult>>&&);
    ~WebXRTransientInputHitTestResult();

    const WebXRInputSource& inputSource() const;
    const Vector<RefPtr<WebXRHitTestResult>>& results() const;

private:
    WebXRTransientInputHitTestResult(Ref<WebXRInputSource>&&, Vector<RefPtr<WebXRHitTestResult>>&&);

    Ref<WebXRInputSource> m_inputSource;
    Vector<RefPtr<WebXRHitTestResult>> m_results;
};

} // namespace WebCore

#endif // ENABLE(WEBXR_HIT_TEST)

==> webkit2gtk_2.51.4.orig.tar.xz: webkitgtk-2.51.4/Source/WebCore/Modules/webxr/WebXRTransientInputHitTestResult.h <==
/*
 * Copyright (C) 2025 Igalia S.L. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEBXR_HIT_TEST)

#include <wtf/Ref.h>
#include <wtf/RefCounted.h>
#include <wtf/TZoneMalloc.h>
#include <wtf/Vector.h>

namespace WebCore {

class WebXRInputSource;
class WebXRHitTestResult;

class WebXRTransientInputHitTestResult : public RefCounted<WebXRTransientInputHitTestResult> {
    WTF_MAKE_TZONE_OR_ISO_ALLOCATED(WebXRTransientInputHitTestResult);
public:
    static Ref<WebXRTransientInputHitTestResult> create(Ref<WebXRInputSource>&&, Vector<Ref<WebXRHitTestResult>>&&);
    ~WebXRTransientInputHitTestResult();

    const WebXRInputSource& inputSource() const;
    const Vector<Ref<WebXRHitTestResult>>& results() const;

private:
    WebXRTransientInputHitTestResult(Ref<WebXRInputSource>&&, Vector<Ref<WebXRHitTestResult>>&&);

    Ref<WebXRInputSource> m_inputSource;
    Vector<Ref<WebXRHitTestResult>> m_results;
};

} // namespace WebCore

#endif // ENABLE(WEBXR_HIT_TEST)
